==> nextcloud-15.0.5p1.tgz: nextcloud/apps/comments/l10n/fr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentaires",
    "You commented" : "Vous avez commenté",
    "%1$s commented" : "%1$s a commenté",
    "{author} commented" : "{author} a commenté",
    "You commented on %1$s" : "Vous avez commenté %1$s",
    "You commented on {file}" : "Vous avez commenté {file}",
    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
    "{author} commented on {file}" : "{author} a commenté sur {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"{file}\", dans un commentaire par un utilisateur qui a été supprimé depuis lors.",
    "{user} mentioned you in a comment on “{file}”" : "{user} vous a mentionné⋅e dans un commentaire sur “{file}”",
    "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
    "Edit comment" : "Modifier le commentaire",
    "Delete comment" : "Supprimer le commentaire",
    "New comment …" : "Nouveau commentaire...",
    "Post" : "Poster",
    "Cancel" : "Annuler",
    "[Deleted user]" : "[Utilisateur supprimé]",
    "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
    "More comments …" : "Plus de commentaires ...",
    "Save" : "Enregistrer",
    "Allowed characters {count} of {max}" : "{count} sur {max} caractères autorisés",
    "Error occurred while retrieving comment with ID {id}" : "Une erreur est survenue lors de la récupération du commentaire avec l'ID {id}",
    "Error occurred while updating comment with id {id}" : "Une erreur est survenue lors de la mise à jour du commentaire avec l'id {id}",
    "Error occurred while posting comment" : "Une erreur est survenue lors de l'envoi du commentaire",
    "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus"],
    "Comment" : "Commenter",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"%s\", dans un commentaire par un utilisateur qui a été supprimé depuis lors.",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vous a mentionné⋅e dans un commentaire sur “%2$s”"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/comments/l10n/fr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commentaires",
    "You commented" : "Vous avez commenté",
    "%1$s commented" : "%1$s a commenté",
    "{author} commented" : "{author} a commenté",
    "You commented on %1$s" : "Vous avez commenté %1$s",
    "You commented on {file}" : "Vous avez commenté {file}",
    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
    "{author} commented on {file}" : "{author} a commenté sur {file}",
    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vous a mentionné dans un commentaire sur \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
    "Edit comment" : "Modifier le commentaire",
    "Delete comment" : "Supprimer le commentaire",
    "Cancel edit" : "Annuler les modifications",
    "Post comment" : "Publier le commentaire",
    "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
    "No more messages" : "Aucun autre message",
    "Retry" : "Réessayer",
    "Unable to load the comments list" : "Impossible de charger la liste des commentaires",
    "_%n unread comment_::_%n unread comments_" : ["%n commentaire non lu","%n commentaires non lus"],
    "_1 new comment_::_{unread} new comments_" : ["1 nouveau commentaire","{unread} nouveaux commentaires"],
    "Comment" : "Commenter",
    "An error occurred while trying to edit the comment" : "Une erreur s'est produite lors de la tentative de modification du commentaire",
    "Comment deleted" : "Commentaire supprimé",
    "An error occurred while trying to delete the comment" : "Une erreur s'est produite lors de la tentative de suppression du commentaire",
    "An error occurred while trying to create the comment" : "Une erreur s'est produite lors de la tentative de création du commentaire",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Vous avez été mentionné sur \"{file}\", dans un commentaire par un utilisateur qui a été supprimé depuis lors.",
    "{user} mentioned you in a comment on “{file}”" : "{user} vous a mentionné⋅e dans un commentaire sur “{file}”",
    "New comment …" : "Nouveau commentaire...",
    "Post" : "Poster",
    "Cancel" : "Annuler",
    "[Deleted user]" : "[Utilisateur supprimé]",
    "More comments …" : "Plus de commentaires ...",
    "Save" : "Enregistrer",
    "Allowed characters {count} of {max}" : "{count} sur {max} caractères autorisés",
    "Error occurred while retrieving comment with ID {id}" : "Une erreur est survenue lors de la récupération du commentaire avec l'ID {id}",
    "Error occurred while updating comment with id {id}" : "Une erreur est survenue lors de la mise à jour du commentaire avec l'id {id}",
    "Error occurred while posting comment" : "Une erreur est survenue lors de l'envoi du commentaire"
},
"nplurals=2; plural=(n > 1);");
